@@ -6,7 +6,7 @@ from urlbreadcrumbs import url as burl
 
 test1_urls = patterns('',
     url(r'^$', simple_view, {'template' : 'urlbreadcrumbs_tests/t1.html'}, name='t1home'),
-    burl(r'^aaa/$', simple_view, {'template' : 'urlbreadcrumbs_tests/t1sub.html'}, name='t1aaa', verbose_name = "Test1 subpage"),
+    burl(r'^aaa/$', simple_view, {'template' : 'urlbreadcrumbs_tests/t1sub.html'}, name='t1aaa', verbose_name = "Test1 subpage via custom url function"),
 )
 
 test2_urls = patterns('',
@@ -17,5 +17,5 @@ test2_urls = patterns('',
 urlpatterns = patterns('',
     url(r'^$', simple_view, {'template' : 'urlbreadcrumbs_tests/index.html'}, name='index'),
     burl(r'^test1/', include(test1_urls)),
-    burl(r'^test2/', include(test2_urls)),
+    url(r'^test2/', include(test2_urls)),
 )
